@@ -15,54 +15,32 @@ from kraken_html.html_navbar import Html_navbar
 
 class Kraken_html:
 
-    def __init__(self):
+    def __init__(self, title = None):
 
 
         self.nav = []
-        self.title_nav = None
-
-        self.input_record = {}
-
-        self.input_records = []
-
-        self._keys = []
+        self.title = title
 
 
-    @property
-    def keys(self):
-        
-        if self._keys:
-            return self._keys
 
-        else:
-            return self._get_keys(self.value)
+    def table(self, value):
 
 
-    @keys.setter
-    def keys(self, value):
-
-        self._keys = value
-
-
-    def table(self, value = None):
-
-        if value:
-            self.value = value
-
         html_table = Html_table()
+        keys = self._get_keys(value)
 
-        return html_table.table(self.keys, self.value)
+        return html_table.table(keys, value)
 
 
     def record(self, value):
 
-        if value:
-            self.value = value
-
 
         html_record = Html_record()
 
-        return html_record.record(self.keys, self.value)
+        keys = self._get_keys(value)
+
+
+        return html_record.record(keys, value)
 
 
 
@@ -75,15 +53,13 @@ class Kraken_html:
         return 
 
 
-    def cards(self, value = None):
+    def cards(self, value):
 
-        if value:
-            self.value = value
 
 
         html_card = Html_card()
 
-        return html_card.cards(self.value)
+        return html_card.cards(value)
 
 
 
@@ -120,10 +96,10 @@ class Kraken_html:
 
         
         
-        html_nav = self.navbar('Test title', self.nav)
+        html_nav = self.navbar(self.title, self.nav)
 
 
-        content = self.bootstrap(html_nav, self.title_nav, content)
+        content = self.bootstrap(html_nav, self.title, content)
 
         return content
 
